@@ -10,10 +10,12 @@ Utilities to define configuration values
 
 import os
 import os.path as osp
+import platform
 import sys
 
 from spyder.config.base import _
-from spyder.utils import iofuncs
+
+from spyder_kernels.utils import iofuncs
 
 
 #==============================================================================
@@ -26,11 +28,12 @@ EDIT_FILETYPES = [
     (_("C files"), ('.c', '.h')),
     (_("C++ files"), ('.cc', '.cpp', '.cxx', '.h', '.hh', '.hpp', '.hxx')),
     (_("OpenCL files"), ('.cl', )),
-    (_("Fortran files"), ('.f', '.for', '.f77', '.f90', '.f95', '.f2k')),
+    (_("Fortran files"), ('.f', '.for', '.f77', '.f90', '.f95', '.f2k',
+                          '.f03', '.f08')),
     (_("IDL files"), ('.pro', )),
     (_("MATLAB files"), ('.m', )),
     (_("Julia files"), ('.jl',)),
-    (_("Yaml files"), ('.yaml','.yml',)),
+    (_("Yaml files"), ('.yaml', '.yml',)),
     (_("Patch and diff files"), ('.patch', '.diff', '.rej')),
     (_("Batch files"), ('.bat', '.cmd')),
     (_("Text files"), ('.txt',)),
@@ -97,7 +100,16 @@ def _get_pygments_extensions():
             lexer_exts = [le for le in lexer_exts if not le.endswith('_*')]
             extensions = extensions + list(lexer_exts) + list(other_exts)
 
-    return sorted(list(set(extensions)))
+    extensions = list(set(extensions))
+
+    # A non-ascii file extension causes issues for macOS
+    # See spyder-ide/spyder#22248
+    try:
+        extensions.remove('.' + chr(128293))
+    except ValueError:
+        pass
+
+    return sorted(extensions)
 
 
 #==============================================================================
@@ -114,14 +126,17 @@ def get_filter(filetypes, ext):
         return ''
 
 
-def get_edit_filetypes():
+def get_edit_filetypes(ignore_pygments_extensions=True):
     """Get all file types supported by the Editor"""
-    # The filter details are not hidden on Windows, so we can't use
-    # all Pygments extensions on that platform
-    if os.name == 'nt':
+    # The filter details are not hidden on Windows, so we can't use all
+    # Pygments extensions on that platform.
+    if os.name == 'nt' and ignore_pygments_extensions:
         supported_exts = []
     else:
-        supported_exts = _get_pygments_extensions()
+        try:
+            supported_exts = _get_pygments_extensions()
+        except Exception:
+            supported_exts = []
 
     # NOTE: Try to not add too much extensions to this list to not
     # make the filter look too big on Windows
@@ -146,13 +161,14 @@ def get_edit_filters():
 
 def get_edit_extensions():
     """
-    Return extensions associated with the file types
-    supported by the Editor
+    Return extensions associated with the file types supported by the Editor.
     """
-    edit_filetypes = get_edit_filetypes()
-    return _get_extensions(edit_filetypes)+['']
+    edit_filetypes = get_edit_filetypes(ignore_pygments_extensions=False)
+    return _get_extensions(edit_filetypes)
 
 
+EDIT_EXTENSIONS = get_edit_extensions()
+
 #==============================================================================
 # Detection of OS specific versions
 #==============================================================================
@@ -207,3 +223,13 @@ def is_anaconda():
     """
     is_conda = osp.exists(osp.join(sys.prefix, 'conda-meta'))
     return is_conda
+
+
+def is_wsl():
+    """Detect if we are running in WSL."""
+    if (
+        platform.system() == "Linux"
+        and "microsoft" in platform.release().lower()
+    ):
+        return True
+    return False
